########################################
##   DEFAULT CUSTOM FILE FOR GFF2PS   ##
########################################
#
# $Id: brown.a3.rc,v 1.3 2001/08/31 17:42:12 jabril Exp $
#
# L ######PAGE LAYOUT & PROGRAM OPTIONS######
#
page_size=a3
page_orientation=Landscape
# page_number=1
blocks_x_page=4
nucleotides_x_line=30000
zoom=*..*
# major_tickmarks_num=10
# minor_tickmarks_num=10
major_tickmarks_nucleotides=1000
minor_tickmarks_nucleotides=250
#
left_source_label_width=2.5cm
show_blocks_top-bottom=off
#
group_label_scale=2
#
#
# F ############GENOMIC FEATURES############
#
*::fill_shape_mode=1_color
LINE/L2::feature_color=verydarkred
SINE/Alu::feature_color=verydarkgreen
SINE/MIR::feature_color=verydarkbrown
LTR/ERV1::feature_color=verydarkblue
Low_complexity::feature_color=verydarkyellow
Simple_repeat::feature_color=verydarkorange
#
# G ############GROUP FEATURES##############
#
*::group_line=none
*::group_shape=thick_line
#
# S ############SOURCE FEATURES#############
#
*::unfold_grouped_ungrouped=off
*::unfold_ungrouped_line=off
*::unfold_grouped_line=off
*::range=none
*::source_line_color=black
*::source_line=long_dotted
#
annotation::feature_color=darkgreen
annotation::group_color=verydarkgreen
SGP.3X::feature_color=darkorange
SGP.3X::group_color=verydarkorange
SGP.homol::feature_color=darkorange
SGP.homol::group_color=verydarkorange
geneid_v1.0::feature_color=lightviolet
geneid_v1.0::group_color=darkviolet
genscan::feature_color=blue
genscan::group_color=verydarkblue
tblastx.3X::feature_color=red
tblastx.3X::group_color=verydarkred
tblastx.homol::feature_color=red
tblastx.homol::group_color=verydarkred
# RepeatMasker::feature_color=####
#
annotation::left_label=ANNOTATION
SGP.3X::left_label=SGP 3X
SGP.homol::left_label=SGP
geneid_v1.0::left_label=GENEID
genscan::left_label=GENSCAN
tblastx.3X::left_label=TBLASTX 3X
tblastx.homol::left_label=TBLASTX
RepeatMasker::left_label=REPEATS
